# rankexpansion

https://pypi.org/project/rankexpansion/

pip install rankexpansion

To use this either library have an OPENAI_API_KEY environ variable
set as your key or set openai.api_key= "your key" before you use any 
functions in this package